@@ -511,7 +511,10 @@ save_newline (GbWidgetGetArgData * data)
 
 static void
 save_string_internal (GbWidgetGetArgData * data, const gchar * tag_name,
-		      const gchar * tag_value, gboolean translatable)
+		      const gchar * tag_value,
+		      gboolean translatable,
+		      const gchar *translator_comments,
+		      gboolean has_context_prefix)
 {
   gchar *tag_name_start;
 
@@ -535,7 +538,19 @@ save_string_internal (GbWidgetGetArgData * data, const gchar * tag_name,
   g_string_append_c (data->buffer, '"');
 
   if (translatable)
-    g_string_append (data->buffer, " translatable=\"yes\"");
+    {
+      g_string_append (data->buffer, " translatable=\"yes\"");
+
+      if (has_context_prefix)
+	g_string_append (data->buffer, " context=\"yes\"");
+
+      if (translator_comments && *translator_comments)
+	{
+	  g_string_append (data->buffer, " comments=\"");
+	  save_buffer_add_string (data->buffer, translator_comments);
+	  g_string_append_c (data->buffer, '"');
+	}
+    }
 
   g_string_append_c (data->buffer, '>');
   save_buffer_add_string (data->buffer, tag_value);
@@ -546,7 +561,22 @@ void
 save_string (GbWidgetGetArgData * data, const gchar * tag_name,
 	     const gchar * tag_value)
 {
-  save_string_internal (data, tag_name, tag_value, FALSE);
+  save_string_internal (data, tag_name, tag_value, FALSE, NULL, FALSE);
+}
+
+
+void
+save_translatable_string_internal (GbWidgetGetArgData * data,
+				   const gchar * tag_name,
+				   const gchar * tag_value)
+{
+  gboolean translatable, context;
+  gchar *comments;
+
+  glade_util_get_translation_properties (data->widget, tag_name, &translatable,
+					 &comments, &context);
+  save_string_internal (data, tag_name, tag_value, translatable,
+			comments, context);
 }
 
 
@@ -554,7 +584,7 @@ void
 save_translatable_string (GbWidgetGetArgData * data, const gchar * tag_name,
 			  const gchar * tag_value)
 {
-  save_string_internal (data, tag_name, tag_value, TRUE);
+  save_translatable_string_internal (data, tag_name, tag_value);
   if (data->save_translatable_strings)
     save_add_translatable_string (data, tag_value);
 }
@@ -572,9 +602,7 @@ void
 save_translatable_text (GbWidgetGetArgData * data, const gchar * tag_name,
 			const gchar * tag_value)
 {
-  save_string_internal (data, tag_name, tag_value, TRUE);
-  if (data->save_translatable_strings)
-    save_add_translatable_string (data, tag_value);
+  save_translatable_string (data, tag_name, tag_value);
 }
 
 
@@ -588,7 +616,8 @@ save_translatable_text_in_lines (GbWidgetGetArgData * data,
 {
   /* FIXME: This probably won't work if other apps just try to translate the
      entire string. */
-  save_string_internal (data, tag_name, tag_value, TRUE);
+  save_translatable_string_internal (data, tag_name, tag_value);
+
   if (data->save_translatable_strings && tag_value)
     {
       gchar *items, *pos, *items_end;
