@@ -21,7 +21,9 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifndef _WIN32
 #include <unistd.h>
+#endif
 #include <dirent.h>
 #include <errno.h>
 
@@ -1597,17 +1599,26 @@ glade_util_get_next_free_project_directory (gchar **project_directory_return,
 {
   GladeError *error = NULL;
   gchar *projects_dir, *project_string, *subdir;
+  const gchar *home_dir;
   DIR *directory;
   struct dirent *entry;
   gint project_num, max_project_num, project_string_len;
   gint num_matched, chars_matched;
 
+  home_dir = g_get_home_dir ();
+  if (home_dir)
+    {
+      projects_dir = glade_util_make_absolute_path (home_dir, _("Projects"));
+    }
+  else
+    {
 #ifdef _WIN32
-  projects_dir = "C:\\Projects";
+      projects_dir = g_strdup ("C:\\Projects");
 #else
-  projects_dir = glade_util_make_absolute_path (g_get_home_dir (),
-						_("Projects"));
+      /* Just use the root directory. Though it probably won't be writable. */
+      projects_dir = g_strdup (G_DIR_SEPARATOR_S);
 #endif
+    }
 
   /* Step through the 'Projects' directory, if it exists, to find
      subdirectories named 'projectXX', and get the highest number used so
@@ -2245,3 +2256,49 @@ glade_util_uri_list_parse (const gchar *uri_list)
   return g_list_reverse (result);
 }
 
+
+void
+glade_util_get_translation_properties (GtkWidget *widget,
+				       const gchar *property_name,
+				       gboolean *translatable,
+				       gchar **comments,
+				       gboolean *context)
+{
+  gchar buffer[1024];
+
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  sprintf (buffer, "%s:::comments", property_name);
+  *comments = g_object_get_data (G_OBJECT (widget), buffer);
+
+  /* This defaults to TRUE if no object data is set. */
+  sprintf (buffer, "%s:::not_translatable", property_name);
+  *translatable = g_object_get_data (G_OBJECT (widget), buffer) ? FALSE : TRUE;
+
+  /* This defaults to FALSE if no object data is set. */
+  sprintf (buffer, "%s:::context", property_name);
+  *context = g_object_get_data (G_OBJECT (widget), buffer) ? TRUE : FALSE;
+}
+
+
+void
+glade_util_set_translation_properties (GtkWidget *widget,
+				       const gchar *property_name,
+				       gboolean translatable,
+				       const gchar *comments,
+				       gboolean context)
+{
+  gchar buffer[1024];
+
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  sprintf (buffer, "%s:::comments", property_name);
+  g_object_set_data_full (G_OBJECT (widget), buffer,
+			  g_strdup (comments), comments ? g_free : NULL);
+
+  sprintf (buffer, "%s:::not_translatable", property_name);
+  g_object_set_data (G_OBJECT (widget), buffer, translatable ? NULL : "N");
+
+  sprintf (buffer, "%s:::context", property_name);
+  g_object_set_data (G_OBJECT (widget), buffer, context ? "Y" : NULL);
+}
