@@ -356,7 +356,22 @@ FILE*	  glade_util_fopen			(const gchar	*filename_utf8,
 						 const gchar	*mode);
 
 /* Gets a list of file names from a text/uri-list */
-GList *glade_util_uri_list_parse (const gchar* uri_list);
+GList	 *glade_util_uri_list_parse		(const gchar	*uri_list);
+
+/* Gets the extra translation properties stored inside the widget data. */
+void	  glade_util_get_translation_properties (GtkWidget	*widget,
+						 const gchar	*property_name,
+						 gboolean	*translatable,
+						 gchar	       **comments,
+						 gboolean	*context);
+
+/* Sets the extra translation properties stored inside the widget data. */
+void	  glade_util_set_translation_properties (GtkWidget	*widget,
+						 const gchar	*property_name,
+						 gboolean	 translatable,
+						 const gchar	*comments,
+						 gboolean	 context);
+
 
 #ifdef __cplusplus
 }
